@@ -6,9 +6,6 @@ import pandas as pd
 from re import findall
 from typing import Union, Optional
 from warnings import warn
-from ibm_watson_machine_learning.helpers.connections.flight_service import (
-    FlightConnection,
-)
 from ibm_watson_machine_learning.helpers.connections.local import LocalBatchReader
 from ibm_watson_machine_learning.utils.autoai.enums import SamplingTypes
 
@@ -67,7 +64,7 @@ class ExperimentIterableDataset(IterableDataset):
 
     """
 
-    connection: Union[FlightConnection, LocalBatchReader] = None
+    connection: Union["FlightConnection", LocalBatchReader] = None
 
     def __init__(
         self,
@@ -120,12 +117,16 @@ class ExperimentIterableDataset(IterableDataset):
 
         # if number_of_batch_rows is provided, batch_size does not matter anymore
         if self.authorized:
+            is_cos_asset = bool(kwargs.get("flight_parameters", {}).get('datasource_type', {}).get('entity', {}).get('name', '') == 'bluemixcloudobjectstorage')
             # first used headers from experiment metadata if they were set.
             headers_ = None
             if self.experiment_metadata.get("headers"):
                 headers_ = self.experiment_metadata.get("headers")
             elif self._wml_client is not None:
                 headers_ = self._wml_client._get_headers()
+
+            from ibm_watson_machine_learning.helpers.connections.flight_service import FlightConnection
+
             self.connection = FlightConnection(
                 headers=headers_,
                 sampling_type=self.sampling_type,
@@ -134,7 +135,7 @@ class ExperimentIterableDataset(IterableDataset):
                 params=self.experiment_metadata,
                 project_id=self.experiment_metadata.get("project_id", getattr(self._wml_client, 'default_project_id', None)),
                 space_id=self.experiment_metadata.get("space_id", getattr(self._wml_client, 'default_space_id', None)),
-                asset_id=dict_connection.get("location", {}).get("id"),
+                asset_id=None if is_cos_asset else dict_connection.get("location", {}).get("id"), #do not pass asset id for data assets located on COS
                 connection_id=dict_connection.get("connection", {}).get("id"),
                 data_location=dict_connection,
                 data_size_limit=self.sample_size_limit,
