@@ -17,13 +17,14 @@ import os
 import time
 from typing import TYPE_CHECKING, Any, Dict, Union, List, Optional
 
+import pandas as pd
 from pandas import DataFrame, concat
 
 from .base_deployment import BaseDeployment
 from ..helpers import DataConnection, AssetLocation
 from ..utils import StatusLogger, print_text_header_h1
 from ..utils.autoai.connection import validate_source_data_connections, validate_deployment_output_connection
-from ..utils.autoai.utils import init_cos_client, try_load_dataset
+from ..utils.autoai.utils import init_cos_client, try_load_dataset, convert_dataframe_to_fields_values_payload
 from ..utils.autoai.errors import NoneDataConnection
 from ..utils.deployment.errors import BatchJobFailed, MissingScoringResults
 from ..wml_client_error import WMLClientError
@@ -171,7 +172,7 @@ class Batch(BaseDeployment):
 
     @BaseDeployment._project_to_space_to_project
     def run_job(self,
-                payload: Union[DataFrame, List[DataConnection]],
+                payload: Union[DataFrame, List[DataConnection], Dict[str, DataFrame], Dict[str, DataConnection]] = pd.DataFrame(),
                 output_data_reference: 'DataConnection' = None,
                 transaction_id: str = None,
                 background_mode: 'bool' = True) -> Union[Dict, Dict[str, List], DataConnection]:
@@ -215,8 +216,70 @@ class Batch(BaseDeployment):
         >>> payload_reference = DataConnection(location=DSLocation(asset_id=asset_id))
         >>> score_details = deployment.score(payload=payload_reference, output_data_filename = "scoring_output.csv")
         """
+
+        if isinstance(payload, dict):
+            observations = payload.get('observations', pd.DataFrame())
+            supporting_features = payload.get('supporting_features')
+
+            if isinstance(observations, DataFrame) and \
+                    (isinstance(supporting_features, DataFrame) or supporting_features is None):
+                observations_payload = convert_dataframe_to_fields_values_payload(observations, return_values_only=True)
+                observations_payload['id'] = 'observations'
+                input_data = [observations_payload]
+
+                if supporting_features is not None:
+                    supporting_features_payload = convert_dataframe_to_fields_values_payload(supporting_features, return_values_only=True)
+                    supporting_features_payload['id'] = 'supporting_features'
+                    input_data.append(supporting_features_payload)
+
+                scoring_payload = {
+                    self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA: input_data
+                }
+
+            elif isinstance(observations, DataConnection) and \
+                    (isinstance(supporting_features, DataConnection) or supporting_features is None):
+
+                observations.id = 'observations'
+                input_data = [observations]
+                if supporting_features is not None:
+                    supporting_features.id = 'supporting_features'
+                    input_data.append(supporting_features)
+
+                for data_conn in input_data:
+                    if hasattr(data_conn, 'location') and isinstance(data_conn.location, AssetLocation):
+                        data_conn.location.wml_client = self._target_workspace.wml_client
+
+                input_data = validate_source_data_connections(source_data_connections=input_data,
+                                                              workspace=self._target_workspace,
+                                                              deployment=True)
+                input_data = [data_connection._to_dict() for data_connection in input_data]
+
+                if output_data_reference is None:
+                    raise ValueError("\"output_data_reference\" should be provided.")
+
+                if isinstance(output_data_reference, DataConnection):
+
+                    # wml_client sets correct href for Data Assets
+                    if hasattr(output_data_reference, 'location') and isinstance(output_data_reference.location,
+                                                                                 AssetLocation):
+                        output_data_reference.location.wml_client = self._target_workspace.wml_client
+
+                    output_data_reference = validate_deployment_output_connection(
+                        results_data_connection=output_data_reference,
+                        workspace=self._target_workspace,
+                        source_data_connections=input_data)
+                    output_data_reference = output_data_reference._to_dict()
+
+                scoring_payload = {
+                    self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA_REFERENCES: input_data,
+                    self._target_workspace.wml_client.deployments.ScoringMetaNames.OUTPUT_DATA_REFERENCE:
+                        output_data_reference}
+
+            else:
+                raise TypeError('Missing data observations in payload or observations '
+                                 'or supporting_features are not pandas.DataFrames.')
         # note: support for DataFrame payload
-        if isinstance(payload, DataFrame):
+        elif isinstance(payload, DataFrame):
             scoring_payload = {
                 self._target_workspace.wml_client.deployments.ScoringMetaNames.INPUT_DATA: [{'values': payload}]
             }
