@@ -14,6 +14,7 @@
 
 from typing import TYPE_CHECKING, Any, Dict, Union, List, Optional
 
+import pandas as pd
 from pandas import DataFrame
 
 from .base_deployment import BaseDeployment
@@ -168,14 +169,15 @@ class WebService(BaseDeployment):
         return super().get_params()
 
     @BaseDeployment._project_to_space_to_project
-    def score(self, payload: 'DataFrame', transaction_id: str = None) -> Dict[str, List]:
+    def score(self, payload: Union[dict, 'DataFrame'] = pd.DataFrame(), transaction_id: str = None) -> Dict[str, List]:
         """
         Online scoring on WML. Payload is passed to the WML scoring endpoint where model have been deployed.
 
         Parameters
         ----------
-        payload: pandas.DataFrame, required
-            DataFrame with data to test the model.
+        payload: pandas.DataFrame or dictionary, required
+            DataFrame with data to test the model or dictionary with keys `observations` and `supporting_features` and
+            DataFrames with data for observations and supporting_features to score forecasting models.
 
         transaction_id: str, optional
             Can be used to indicate under which id the records will be saved into payload table in IBM OpenScale.
