@@ -20,7 +20,7 @@ from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
     TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, ForecastingAlgorithms, PredictionType, Metrics, \
     Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass, ClassificationAlgorithmsCP4D,
-    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D, SamplingTypes, ImputationStrategy)
+    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D, SamplingTypes, ImputationStrategy, ForecastingPipelineTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
     NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
     TSNotSupported, ParamOutOfRange, ImputationListNotSupported, MissingEstimatorForExistingBatchedEstimator
@@ -452,6 +452,10 @@ class AutoAI(BaseExperiment):
         elif 'global_stage_include_batched_ensemble_estimators' in kwargs:
             include_batched_ensemble_estimators = kwargs.pop('global_stage_include_batched_ensemble_estimators')  # TODO to be removed
 
+        # note: convert `timeseries` type to PredictionType.FORECASTING:
+        if prediction_type == 'timeseries':
+            prediction_type = PredictionType.FORECASTING
+
         # TS exogenous, to be removed
         feature_columns = None
         pipeline_types = None
@@ -480,7 +484,7 @@ class AutoAI(BaseExperiment):
                         self._workspace.wml_client.wml_credentials['version'].startswith('3.5')):
             raise TSNotSupported()
 
-        if prediction_type == PredictionType.FORECASTING:
+        if prediction_type in (PredictionType.FORECASTING, 'timeseries'):
             if not numerical_imputation_strategy and type(numerical_imputation_strategy) is not list:
                 numerical_imputation_strategy = ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS
             elif not numerical_imputation_strategy and type(numerical_imputation_strategy) is list:
@@ -519,10 +523,14 @@ class AutoAI(BaseExperiment):
         def translate_str_include_batched_ensemble_estimators_param(x):
             return [translate_batched_estimator_string_to_enum(estimator) for estimator in x]
 
+        def translate_str_pipeline_types_param(x):
+            return [ForecastingPipelineTypes(pipeline_type) for pipeline_type in x]
+
         categorical_imputation_strategy = translate_str_imputation_param(categorical_imputation_strategy)
         numerical_imputation_strategy = translate_str_imputation_param(numerical_imputation_strategy)
         include_only_estimators = translate_str_include_only_estimators_param(include_only_estimators) if include_only_estimators else None
         include_batched_ensemble_estimators = translate_str_include_batched_ensemble_estimators_param(include_batched_ensemble_estimators) if include_batched_ensemble_estimators else None
+        pipeline_types = translate_str_pipeline_types_param(pipeline_types) if pipeline_types != None else None
 
         if include_batched_ensemble_estimators:
             for batched_estimator in include_batched_ensemble_estimators:
