@@ -150,7 +150,7 @@ class WMLEngine(BaseEngine):
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'text_columns'] = self._auto_pipelines_parameters.get('text_columns_names')
                 # end of Text transformer parameters
-            if self._auto_pipelines_parameters.get('retrain_on_holdout'):
+            if self._auto_pipelines_parameters.get('retrain_on_holdout') is not None:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
@@ -243,7 +243,7 @@ class WMLEngine(BaseEngine):
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'compute_pipeline_notebooks_flag'] = self._auto_pipelines_parameters.get('notebooks', False)
-            if self._auto_pipelines_parameters.get('retrain_on_holdout'):
+            if self._auto_pipelines_parameters.get('retrain_on_holdout') is not None:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
