@@ -27,11 +27,12 @@ from ibm_watson_machine_learning.helpers.connections import (
 from ibm_watson_machine_learning.preprocessing import DataJoinPipeline
 from ibm_watson_machine_learning.utils.autoai.enums import (
     RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes,
-    ForecastingPipelineTypes)
+    ForecastingPipelineTypes, PredictionType)
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
-    ForecastingUnsupportedOperation, LibraryNotCompatible, InvalidDataAsset, TestDataNotPresent)
+    ForecastingUnsupportedOperation, LibraryNotCompatible, InvalidDataAsset, TestDataNotPresent,
+    FutureExogenousFeaturesNotSupported)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale, all_logging_disabled
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
@@ -324,27 +325,21 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         Example
         -------
         >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> from ibm_watson_machine_learning.helpers import DataConnection, S3Connection, S3Location
+        >>> from ibm_watson_machine_learning.helpers import DataConnection, S3Location
         >>>
         >>> experiment = AutoAI(credentials, ...)
         >>> remote_optimizer = experiment.optimizer(...)
         >>>
         >>> remote_optimizer.fit(
         >>>     training_data_connection=[DataConnection(
-        >>>         connection=S3Connection(
-        >>>             endpoint_url="https://s3.us.cloud-object-storage.appdomain.cloud",
-        >>>             access_key_id="9c92n0scodfa",
-        >>>             secret_access_key="0ch827gf9oiwdn0c90n20nc0oms29j"),
+        >>>         connection_asset_id=connection_id,
         >>>         location=S3Location(
         >>>             bucket='automl',
         >>>             path='german_credit_data_biased_training.csv')
         >>>         )
         >>>     )],
         >>>     DataConnection(
-        >>>         connection=S3Connection(
-        >>>             endpoint_url="https://s3.us.cloud-object-storage.appdomain.cloud",
-        >>>             access_key_id="9c92n0scodfa",
-        >>>             secret_access_key="0ch827gf9oiwdn0c90n20nc0oms29j"),
+        >>>         connection_asset_id=connection_id,
         >>>         location=S3Location(
         >>>             bucket='automl',
         >>>             path='')
@@ -738,7 +733,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                              'Should be either PipelineTypes.SKLEARN or PipelineTypes.LALE')
 
     # note: predict on top of the best computed pipeline, best pipeline is downloaded for the first time
-    def predict(self, X: Union['DataFrame', 'ndarray']) -> 'ndarray':
+    def predict(self, X: Union['DataFrame', 'ndarray']=None, observations: Union['DataFrame', 'ndarray']=None,
+                supporting_features: Union['DataFrame', 'ndarray']=None) -> 'ndarray':
         """
         Predict method called on top of the best fetched pipeline.
 
@@ -746,11 +742,25 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         ----------
         X: numpy.ndarray or pandas.DataFrame, required
             Test data for prediction
+        observations: numpy.ndarray or pandas.DataFrame,
+            New observations of forecasting data that were used to train AutoAI model. Supported only for forecasting pipelines.
+        supporting_features: numpy.ndarray or pandas.DataFrame,
+            Future values of exogenous features. Supported only for forecasting pipelines.
 
         Returns
         -------
         Numpy ndarray with model predictions.
         """
+        is_forecasting = self.params.get('prediction_type') in (PredictionType.FORECASTING, 'timeseries')
+
+        if not is_forecasting and X is None:
+            raise ValueError("X parameter is required in predict method.")
+        if is_forecasting:
+            if X is not None and observations is not None:
+                raise ValueError("For forecasting the  parameter X should not be used. Please use observations instead of X.")
+            else:
+                X = observations if observations is not None else X
+
         if self.best_pipeline is None:
             # note: automatically download the best computed pipeline
             if self.get_run_status() == RunStateTypes.COMPLETED:
@@ -760,8 +770,19 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                                       reason="Please check the run status with run_status() method.")
             # --- end note
 
+        additional_params = {}
+        if supporting_features is not None:
+            if is_forecasting:
+                additional_params.update(
+                    {'supporting_features': supporting_features if isinstance(supporting_features,
+                                                                           ndarray) else supporting_features.values})
+            else:
+                raise FutureExogenousFeaturesNotSupported(self.params.get('prediction_type'))
+
         if isinstance(X, DataFrame) or isinstance(X, ndarray):
-            return self.best_pipeline.predict(X if isinstance(X, ndarray) else X.values)
+            return self.best_pipeline.predict(X if isinstance(X, ndarray) else X.values, **additional_params)
+        elif X is None and is_forecasting:
+            return self.best_pipeline.predict()
         else:
             raise TypeError("X should be either of type pandas.DataFrame or numpy.ndarray")
 
