@@ -92,22 +92,14 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
         >>>        scoring='roc_auc',
         >>>        max_number_of_estimators=1,
         >>>        training_data_reference = [DataConnection(
-        >>>            connection=S3Connection(
-        >>>                api_key='dncf92ubnpo-asocm0890-2om0c-2nc02nci',
-        >>>                auth_endpoint='https://iam.stage1.ng.bluemix.net/oidc/token',
-        >>>                endpoint_url='https://s3-api.us-geo.objectstorage.softlayer.net'
-        >>>            ),
+        >>>            connection_asset_id=connection_id,
         >>>            location=S3Location(
         >>>                bucket='autoai-bucket',
         >>>                path='iris_dataset.csv',
         >>>            )
         >>>        )],
         >>>        training_result_reference = DataConnection(
-        >>>            connection=S3Connection(
-        >>>                api_key='dncf92ubnpo-asocm0890-2om0c-2nc02nci',
-        >>>                auth_endpoint='https://iam.stage1.ng.bluemix.net/oidc/token',
-        >>>                endpoint_url='https://s3-api.us-geo.objectstorage.softlayer.net'
-        >>>            ),
+        >>>            connection_asset_id=connection_id,
         >>>            location=S3Location(
         >>>                bucket='autoai-bucket',
         >>>                path='.',
