@@ -72,7 +72,7 @@ class DataConnection(BaseDataConnection):
 
     Parameters
     ----------
-    connection: Union[S3Connection], optional
+    connection: Union['NFSConnection', 'ConnectionAsset'], optional
         connection parameters of specific type
 
     location: Union[S3Location, FSLocation, AssetLocation],
@@ -434,8 +434,10 @@ class DataConnection(BaseDataConnection):
                 return_only_holdout=False
             )
 
-            X_train = DataFrame(X_train, columns=self.auto_pipeline_params.get('feature_columns', self.auto_pipeline_params['prediction_columns']))
-            X_holdout = DataFrame(X_holdout, columns=self.auto_pipeline_params.get('feature_columns', self.auto_pipeline_params['prediction_columns']))
+            X_columns = self.auto_pipeline_params.get('feature_columns') if self.auto_pipeline_params.get('feature_columns') else self.auto_pipeline_params['prediction_columns']
+
+            X_train = DataFrame(X_train, columns=X_columns)
+            X_holdout = DataFrame(X_holdout, columns=X_columns)
             y_train = DataFrame(y_train, columns=self.auto_pipeline_params['prediction_columns'])
             y_holdout = DataFrame(y_holdout, columns=self.auto_pipeline_params['prediction_columns'])
 
