@@ -869,7 +869,7 @@ class FlightConnection:
                 self.subsampled_data = data
 
             else:
-                timestamp_column = self.params.get('timestamp_column')
+                timestamp_column = self.params.get('timestamp_column') or self.params.get('timestamp_column_name')
                 if timestamp_column is not None:
                     data = data.sort_values(timestamp_column)
                 self.subsampled_data = data.tail(max_rows)
