@@ -218,7 +218,7 @@ class ScikitPipelineModelArtifact(ModelArtifact):
                     training_props["fields"].append({
                         "name": feature_names[i], "type": type(training_features[0][i]).__name__
                     })
-        elif(isinstance(training_features, xgb.DMatrix)):
+        elif lib_checker.installed_libs[XGBOOST] and isinstance(training_features, xgb.DMatrix):
             for index, feature in enumerate(training_features.feature_names):   #start=0
                 training_props["fields"].append({"name": feature, "type": str(training_features.feature_types[index])})
             is_xgboost_dmatrix = True
@@ -266,7 +266,7 @@ class ScikitPipelineModelArtifact(ModelArtifact):
                     training_props["labels"]["fields"].append({
                         "name": label_column_names[i], "type": type(training_target[0][i]).__name__
                     })
-        elif(isinstance(training_features, xgb.DMatrix)):  #For DMatrix labels is part of training_data and not training_target
+        elif lib_checker.installed_libs[XGBOOST] and isinstance(training_features, xgb.DMatrix):  #For DMatrix labels is part of training_data and not training_target
             training_props["labels"]["fields"].append({"type": str(type(training_features.get_label()[0]).__name__)})
         else:
             raise ValueError("Unsupported label data type %s provided" % (type(training_target)))
