@@ -106,7 +106,7 @@ def validate_results_data_connection(results_data_connection: Union['DataConnect
     # -- end note
     # note: results can be stored only on FS or COS
     if not isinstance(results_data_connection.location, (S3Location, FSLocation)):
-        raise TypeError('Unsupported results location type. Results referance can be stored'
+        raise TypeError('Unsupported results location type. Results reference can be stored'
                         ' only on S3Location or FSLocation.')
     # -- end
     return results_data_connection
