@@ -40,13 +40,13 @@ __all__ = [
 
 class ClassificationAlgorithms(Enum):
     """Classification algorithms that AutoAI could use for IBM Cloud."""
-    EX_TREES = "ExtraTreesClassifierEstimator"
-    GB = "GradientBoostingClassifierEstimator"
-    LGBM = "LGBMClassifierEstimator"
-    LR = "LogisticRegressionEstimator"
-    RF = "RandomForestClassifierEstimator"
-    XGB = "XGBClassifierEstimator"
-    DT = "DecisionTreeClassifierEstimator"
+    EX_TREES = "ExtraTreesClassifier"
+    GB = "GradientBoostingClassifier"
+    LGBM = "LGBMClassifier"
+    LR = "LogisticRegression"
+    RF = "RandomForestClassifier"
+    XGB = "XGBClassifier"
+    DT = "DecisionTreeClassifier"
     SnapDT = "SnapDecisionTreeClassifier"
     SnapRF = "SnapRandomForestClassifier"
     SnapSVM = "SnapSVMClassifier"
@@ -87,14 +87,14 @@ class BatchedClassificationAlgorithms(Enum):
 
 class RegressionAlgorithms(Enum):
     """Regression algorithms that AutoAI could use for IBM Cloud."""
-    RF = "RandomForestRegressorEstimator"
-    RIDGE = "RidgeEstimator"
-    EX_TREES = "ExtraTreesRegressorEstimator"
-    GB = "GradientBoostingRegressorEstimator"
-    LR = "LinearRegressionEstimator"
-    XGB = "XGBRegressorEstimator"
-    LGBM = "LGBMRegressorEstimator"
-    DT = "DecisionTreeRegressorEstimator"
+    RF = "RandomForestRegressor"
+    RIDGE = "Ridge"
+    EX_TREES = "ExtraTreesRegressor"
+    GB = "GradientBoostingRegressor"
+    LR = "LinearRegression"
+    XGB = "XGBRegressor"
+    LGBM = "LGBMRegressor"
+    DT = "DecisionTreeRegressor"
     SnapDT = "SnapDecisionTreeRegressor"
     SnapRF = "SnapRandomForestRegressor"
     SnapBM = "SnapBoostingMachineRegressor"
@@ -123,7 +123,7 @@ class BatchedRegressionAlgorithms(Enum):
     """Batched tree ensemble regression algorithms that AutoAI could use for IBM Cloud."""
     RF = "BatchedTreeEnsembleRegressor(RandomForestRegressor)"
     EX_TREES = "BatchedTreeEnsembleRegressor(ExtraTreesRegressor)"
-    LGBM = "BatchedTreeEnsembleRegressor(LGBMRegressorEstimator)"
+    LGBM = "BatchedTreeEnsembleRegressor(LGBMRegressor)"
     GB = "BatchedTreeEnsembleRegressor(GradientBoostingRegressor)"
     SnapRF = "BatchedTreeEnsembleRegressor(SnapRandomForestRegressor)"
     SnapBM = "BatchedTreeEnsembleRegressor(SnapBoostingMachineRegressor)"
