@@ -58,7 +58,8 @@ __all__ = [
     'InvalidImputationParameterTS',
     'InconsistentImputationListElements',
     'ImputationListNotSupported',
-    'MissingEstimatorForExistingBatchedEstimator'
+    'MissingEstimatorForExistingBatchedEstimator',
+    'FutureExogenousFeaturesNotSupported'
 ]
 
 #  (C) Copyright IBM Corp. 2021.
@@ -415,3 +416,9 @@ class MissingEstimatorForExistingBatchedEstimator(WMLClientError, ValueError):
         WMLClientError.__init__(self, f"There is no corresponding estimator in `include_only_estimators` list for " +
                                 f"{batched_estimator} estimator in `include_batched_ensemble_estimators` list. " +
                                 f"Add {missing_estimator} estimator to `include_only_estimators` list.")
+
+
+class FutureExogenousFeaturesNotSupported(WMLClientError, ValueError):
+    def __init__(self, prediction_type: str):
+        WMLClientError.__init__(self, f"Future Exogenous features are only supported for forecasting."
+                                      f"Current prediction type is: {prediction_type}")
\ No newline at end of file
