@@ -95,6 +95,32 @@ class WMLResource:
 
             return new_el
 
+    def _get_asset_based_resource(self, asset_id, asset_type, get_required_element_from_response):
+        WMLResource._validate_type(asset_id, f'{asset_type}_id', STR_TYPE, False)
+
+        if asset_id:
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_id),
+                                    params=self._client._params(),
+                                    headers=self._client._get_headers())
+
+            return get_required_element_from_response(self._handle_response(200, f'get {asset_type} details', response))
+
+        else:
+            href = self._client.service_instance._href_definitions.get_asset_search_href(asset_type)
+
+            data = {
+                "query": "*:*"
+            }
+
+            response = requests.post(href,
+                                     json=data,
+                                     params=self._client._params(),
+                                     headers=self._client._get_headers())
+
+            return {'resources': [
+                get_required_element_from_response(x)
+                for x in self._handle_response(200, f'get {asset_type}s details', response)['results']]}
+
     @staticmethod
     def _validate_type(el, el_name, expected_type, mandatory=True):
         if el_name is None:
@@ -211,6 +237,9 @@ class WMLResource:
         if pre_defined == "True":
             params.update({u'system_runtimes': u'true'})
 
+        if 'userfs' in params:
+            params.pop('userfs')
+
         if limit is not None:
             if limit < 1:
                 raise WMLClientError('Limit cannot be lower than 1.')
@@ -375,7 +404,7 @@ class WMLResource:
     def _wsd_list_assets(self, asset_type, limit=None):
         _DEFAULT_LIST_LENGTH = 50
         ##For CP4D, check if either spce or project ID is set
-        href = self._client.service_instance._href_definitions.get_wsd_asset_search_href(asset_type)
+        href = self._client.service_instance._href_definitions.get_asset_search_href(asset_type)
         if limit is None:
             data = {
                 "query": "*:*"
@@ -694,24 +723,22 @@ class WMLResource:
 
             attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
             if attachment_response.status_code == 201:
-
-                file = {'file': open(file_path, 'rb')}
-
                 attachment_id = attachment_details["attachment_id"]
                 attachment_url = attachment_details["url1"]
 
                 # STEP 3c.
                 # Upload attachment
-                if not self._ICP:
-                    put_response = requests.put(
-                        attachment_url,
-                        data=open(file_path, 'rb').read()
-                    )
-                else:
-                    put_response = requests.put(
-                        self._wml_credentials['url'] + attachment_url,
-                        files=file
-                    )
+                with open(file_path, 'rb') as f:
+                    if not self._ICP:
+                        put_response = requests.put(
+                            attachment_url,
+                            data=f.read()
+                        )
+                    else:
+                        put_response = requests.put(
+                            self._wml_credentials['url'] + attachment_url,
+                            files={'file': (attachment_meta['name'], f, 'application/octet-stream')}
+                        )
 
                 if put_response.status_code == 201 or put_response.status_code == 200:
                     # STEP 3d.
